summaryrefslogtreecommitdiff
path: root/mpn/mips2/sub_n.s
diff options
context:
space:
mode:
authorKevin Ryde <user42@zip.com.au>2000-04-16 01:20:01 +0200
committerKevin Ryde <user42@zip.com.au>2000-04-16 01:20:01 +0200
commit92a17b1594132bf5f8c7f9782d85ad5b5bb2eba8 (patch)
treed19a83c2fa5195c6d7c22903719653db1020fd83 /mpn/mips2/sub_n.s
parent119565df1ef96a64307d86f42b1925baecabb85d (diff)
downloadgmp-92a17b1594132bf5f8c7f9782d85ad5b5bb2eba8.tar.gz
Change __mpn to __gmpn.
Diffstat (limited to 'mpn/mips2/sub_n.s')
-rw-r--r--mpn/mips2/sub_n.s10
1 files changed, 5 insertions, 5 deletions
diff --git a/mpn/mips2/sub_n.s b/mpn/mips2/sub_n.s
index 3368ef29d..3f51c3627 100644
--- a/mpn/mips2/sub_n.s
+++ b/mpn/mips2/sub_n.s
@@ -1,4 +1,4 @@
# MIPS2 __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and
# store difference in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -29,9 +29,9 @@
.text
.align 2
- .globl __mpn_sub_n
- .ent __mpn_sub_n
-__mpn_sub_n:
+ .globl __gmpn_sub_n
+ .ent __gmpn_sub_n
+__gmpn_sub_n:
.set noreorder
.set nomacro
@@ -117,4 +117,4 @@ __mpn_sub_n:
j $31
or $2,$2,$8
- .end __mpn_sub_n
+ .end __gmpn_sub_n
@@ -1,4 +1,4 @@
- # MIPS2 __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and
+ # MIPS2 __gmpn_sub_n -- Subtract two limb vectors of the same length > 0 and
# store difference in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.